h5pywrappers
============

``h5pywrappers`` is a simple Python library that contains several functions used
to facilitate loading data from and saving data to HDF5 files. These functions
are wrappers that call functions from the h5py_ library.

.. _h5py: https://docs.h5py.org/en/stable/

Setting up h5pywrappers
-----------------------

For instructions on installing the ``h5pywrappers`` library, see the
:ref:`installation_instructions_sec` page.

Learning how to use h5pywrappers
--------------------------------

For those new to the ``h5pywrappers`` library, it is recommended that they take
a look at the :ref:`examples_sec` page, which contain code examples that show
how one can use the ``h5pywrappers`` library. While going through the examples,
readers can consult the :ref:`reference_guide_sec` to understand what each line
of code is doing.

Contents
--------
.. toctree::
   :maxdepth: 6
   :numbered:

   Home <self>
   INSTALL
   Reference <_autosummary/h5pywrappers>
   examples
   license

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
